## ----style, echo=FALSE, results="asis", message=FALSE--------------------
BiocStyle::markdown()
knitr::opts_chunk$set(tidy = FALSE,
                      warning = FALSE,
                      message = FALSE)

## ----echo=FALSE, results='hide', message=FALSE---------------------------
library(org.Hs.eg.db)
library(DOSE)
library(clusterProfiler)
library(ReactomePA)

## ------------------------------------------------------------------------
library(ReactomePA)
data(geneList)
de <- names(geneList)[abs(geneList) > 1.5]
head(de)
x <- enrichPathway(gene=de,pvalueCutoff=0.05, readable=T)
head(summary(x))

## ----fig.height=5, fig.width=8-------------------------------------------
barplot(x, showCategory=8)

## ----fig.height=8, fig.width=8-------------------------------------------
dotplot(x, showCategory=15)

## ----fig.height=16, fig.width=20-----------------------------------------
enrichMap(x, layout=igraph::layout.kamada.kawai, vertex.label.cex = 1)

## ----fig.height=12, fig.width=12-----------------------------------------
cnetplot(x, categorySize="pvalue", foldChange=geneList)

## ----fig.height=8, fig.width=13------------------------------------------
require(clusterProfiler)
data(gcSample)
res <- compareCluster(gcSample, fun="enrichPathway")
plot(res)

## ------------------------------------------------------------------------
y <- gsePathway(geneList, nPerm=100, 
                minGSSize=120, pvalueCutoff=0.2, 
                pAdjustMethod="BH", verbose=FALSE)
res <- summary(y)
head(res)

## ----fig.height=16, fig.width=16-----------------------------------------
enrichMap(y)

## ----fig.height=8, fig.width=10------------------------------------------
gseaplot(y, geneSetID = "1280215")

## ----fig.height=16, fig.width=16-----------------------------------------
viewPathway("E2F mediated regulation of DNA replication", readable=TRUE, foldChange=geneList)

## ----echo=FALSE----------------------------------------------------------
sessionInfo()

